summaryrefslogtreecommitdiffstats
path: root/src/library/basetrackcache.cpp
diff options
context:
space:
mode:
authorUwe Klotz <uklotz@mixxx.org>2020-04-22 17:02:02 +0200
committerUwe Klotz <uklotz@mixxx.org>2020-06-05 13:25:18 +0200
commitf15675aca5e4fc0583c3fc8a76ee713686cf0774 (patch)
tree7da80152d30a7dc593fbba49e2e8eddbc247557a /src/library/basetrackcache.cpp
parentf6ba1d4b676dfce45b691be6f1a6a282d982a6ab (diff)
Switch cover column sorting from legacy hash to digest
Diffstat (limited to 'src/library/basetrackcache.cpp')
-rw-r--r--src/library/basetrackcache.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/library/basetrackcache.cpp b/src/library/basetrackcache.cpp
index c2dcfc95bf..9062ef0297 100644
--- a/src/library/basetrackcache.cpp
+++ b/src/library/basetrackcache.cpp
@@ -411,8 +411,8 @@ void BaseTrackCache::getTrackValueForColumn(TrackPointer pTrack,
fieldIndex(ColumnCache::COLUMN_LIBRARYTABLE_COVERART) == column ||
fieldIndex(ColumnCache::COLUMN_LIBRARYTABLE_COVERART_HASH) == column) {
// For sorting, we give COLUMN_LIBRARYTABLE_COVERART the same value as
- // the cover hash.
- trackValue.setValue(pTrack->getCoverInfo().imageHash());
+ // the cover digest.
+ trackValue.setValue(pTrack->getCoverInfo().imageDigest());
} else if (fieldIndex(ColumnCache::COLUMN_LIBRARYTABLE_COVERART_COLOR) == column) {
trackValue.setValue(mixxx::RgbColor::toQVariant(pTrack->getCoverInfo().color));
} else if (fieldIndex(ColumnCache::COLUMN_LIBRARYTABLE_COVERART_DIGEST) == column) {